pub struct Storage { /* private fields */ }Implementations
Sourceimpl Storage
impl Storage
pub fn new() -> Result<Self>
pub fn load(&self, date: &Date) -> Result<DayData>
pub fn save(&self, day_data: &DayData) -> Result<()>
Sourcepub fn get_file_modified_time(&self, date: &Date) -> Option<SystemTime>
pub fn get_file_modified_time(&self, date: &Date) -> Option<SystemTime>
Get a synthetic monotonic token derived from day revision state. Returns None if the day has never been written.
This is not a wall-clock timestamp; it is used only for equality/ inequality change detection.
pub fn try_get_file_modified_time( &self, date: &Date, ) -> Result<Option<SystemTime>>
pub fn save_active_timer(&self, timer: &TimerState) -> Result<()>
pub fn load_active_timer(&self) -> Result<Option<TimerState>>
pub fn clear_active_timer(&self) -> Result<()>
pub fn diagnostics(&self) -> Result<StorageDiagnostics>